@@ -77,7 +77,7 @@ DccManager::~DccManager()
 
 bool DccManager::installTranslator(const QString &name)
 {
-    QTranslator *translator = new QTranslator();
+    QTranslator *translator = new QTranslator(qApp);
     if (translator->load(QLocale(), name, "_", TRANSLATE_READ_DIR)) {
         qApp->installTranslator(translator);
 #if 1 // 兼容旧版位置
@@ -114,6 +114,8 @@ QQmlApplicationEngine *DccManager::engine()
 void DccManager::setMainWindow(QWindow *window)
 {
     m_window = window;
+    connect(m_window, &QWindow::widthChanged, this, &DccManager::saveSize);
+    connect(m_window, &QWindow::heightChanged, this, &DccManager::saveSize);
 }
 
 void DccManager::loadModules(bool async, const QStringList &dirs)
@@ -430,6 +432,14 @@ DccObject *DccManager::findParent(const DccObject *obj)
     return findObject(path);
 }
 
+void DccManager::saveSize()
+{
+    if (m_dconfig->isValid()) {
+        m_dconfig->setValue(WidthConfig, m_window->width());
+        m_dconfig->setValue(HeightConfig, m_window->height());
+    }
+}
+
 void DccManager::waitShowPage(const QString &url, const QDBusMessage message)
 {
     qCInfo(dccLog()) << "show page:" << url;
@@ -735,13 +745,7 @@ void DccManager::clearData()
     }
     m_plugins->beginDelete();
     clearShowParam();
-    int width_remember = m_window->width();
-    int height_remember = m_window->height();
 
-    if (m_dconfig->isValid()) {
-        m_dconfig->setValue(WidthConfig, width_remember);
-        m_dconfig->setValue(HeightConfig, height_remember);
-    }
     m_window->hide();
     m_window->close();
     // doShowPage(m_root, QString());
@@ -756,9 +760,19 @@ void DccManager::clearData()
     qCDebug(dccLog()) << "delete root end";
 
     qCDebug(dccLog()) << "delete clearData hide:" << m_hideObjects->getChildren().size() << "noAdd:" << m_noAddObjects->getChildren().size() << "noParent" << m_noParentObjects->getChildren().size();
-    delete m_noAddObjects;
-    delete m_noParentObjects;
-    delete m_hideObjects;
+    QVector<DccObject *> deleteObjects;
+    deleteObjects.append(m_hideObjects);
+    deleteObjects.append(m_noAddObjects);
+    deleteObjects.append(m_noParentObjects);
+    while (!deleteObjects.isEmpty()) {
+        auto obj = deleteObjects.takeFirst();
+        QVector<DccObject *> children = obj->getChildren();
+        while (!children.isEmpty()) {
+            delete children.first();
+            children = obj->getChildren();
+        }
+        delete obj;
+    }
     qCDebug(dccLog()) << "delete dccobject";
     qCDebug(dccLog()) << "delete QmlEngine";
     delete m_engine;
