@@ -9,14 +9,20 @@
 #include "accountlistmodel.h"
 
 #include <QFileInfo>
+#include <QPainter>
 #include <QUrl>
 #include <QVariantMap>
 #include <QRegularExpression>
+#include <QPainterPath>
+#include <QBuffer>
 
 #include <DSysInfo>
 
 #include <grp.h>
 
+#define FACEID_NUM    5
+#define Faceimg_SIZE 200
+
 DCORE_USE_NAMESPACE
 namespace dccV25 {
 
